diff -ruN trunk/dvblast.c ajg/dvblast.c
--- trunk/dvblast.c	2009-05-25 14:27:45.000000000 +0100
+++ ajg/dvblast.c	2009-05-24 19:41:09.000000000 +0100
@@ -54,6 +54,7 @@
 int i_bandwidth = 8;
 char *psz_modulation = NULL;
 int b_budget_mode = 0;
+int b_output_udp = 0;
 volatile int b_hup_received = 0;
 
 /*****************************************************************************
@@ -181,13 +182,14 @@
  *****************************************************************************/
 void usage()
 {
-    msg_Err( NULL, "Usage: dvblast -c <config file> [-r <remote socket>] [-t <ttl>] [-o <SSRC IP>] [-i <RT priority>] [-a <adapter>][-n <frontend_num>] -f <frequency> [-s <symbol rate>] [-v <0|13|18>] [-p] [-b <bandwidth>] [-m <modulation] [-u] [-d <dest IP:port>]" );
+    msg_Err( NULL, "Usage: dvblast -c <config file> [-r <remote socket>] [-t <ttl>] [-o <SSRC IP>] [-i <RT priority>] [-a <adapter>][-n <frontend_num>] -f <frequency> [-s <symbol rate>] [-v <0|13|18>] [-p] [-b <bandwidth>] [-m <modulation] [-u] [-U] [-d <dest IP:port>]" );
     msg_Err( NULL, "-v: voltage to apply to the LNB (QPSK)" );
     msg_Err( NULL, "-p: force 22kHz pulses for high-band selection (DVB-S)" );
     msg_Err( NULL, "-m: DVB-C  qpsk|qam_16|qam_32|qam_64|qam_128|qam_256 (default qam_auto)" );
     msg_Err( NULL, "    DVB-T  qam_16|qam_32|qam_64|qam_128|qam_256 (default qam_auto)" );
     msg_Err( NULL, "    DVB-S2 qpsk|psk_8 (default legacy DVB-S)" );
     msg_Err( NULL, "-u: turn on budget mode (no hardware PID filtering)" );
+    msg_Err( NULL, "-U: use raw UDP rather than RTP (required by some IPTV set top boxes)" );
     msg_Err( NULL, "-d: duplicate all received packets to a given port" );
     exit(1);
 }
@@ -206,7 +208,7 @@
     {
         char c;
 
-        if ( (c = getopt(i_argc, pp_argv, "c:r:t:o:i:a:n:f:s:v:pb:m:ud:h")) == -1 )
+        if ( (c = getopt(i_argc, pp_argv, "c:r:t:o:i:a:n:f:s:v:pb:m:uUd:h")) == -1 )
             break;
 
         switch ( c )
@@ -272,6 +274,12 @@
             b_budget_mode = 1;
             break;
 
+ 	case 'U':
+	    b_output_udp = 1;
+	    msg_Err( NULL, "WARNING: Raw UDP output is deprecated.  Please consider using RTP." );
+            msg_Err( NULL, "         For DVB-IP compliance you should use RTP." );
+            break;
+
         case 'd':
         {
             char *psz_token;
diff -ruN trunk/dvblast.h ajg/dvblast.h
--- trunk/dvblast.h	2009-05-25 14:27:45.000000000 +0100
+++ ajg/dvblast.h	2009-05-24 19:07:36.000000000 +0100
@@ -88,6 +88,7 @@
 extern int i_bandwidth;
 extern char *psz_modulation;
 extern int b_budget_mode;
+extern int b_output_udp;
 extern volatile int b_hup_received;
 extern mtime_t i_ca_timeout;
 extern int i_comm_fd;
diff -ruN trunk/output.c ajg/output.c
--- trunk/output.c	2009-05-25 14:27:45.000000000 +0100
+++ ajg/output.c	2009-05-25 15:06:31.000000000 +0100
@@ -132,22 +132,39 @@
     struct iovec p_iov[NB_BLOCKS + 1];
     uint8_t p_rtp_hdr[RTP_SIZE];
     int i;
+    int i_outblocks;
 
-    p_iov[0].iov_base = p_rtp_hdr;
-    p_iov[0].iov_len = sizeof(p_rtp_hdr);
-    rtp_SetHdr( p_output, p_rtp_hdr );
+    i_outblocks = NB_BLOCKS;
 
-    for ( i = 1; i < NB_BLOCKS + 1; i++ )
+    if( b_output_udp == 0 )
     {
-        p_iov[i].iov_base = p_output->pp_blocks[i - 1]->p_ts;
-        p_iov[i].iov_len = TS_SIZE;
+        p_iov[0].iov_base = p_rtp_hdr;
+        p_iov[0].iov_len = sizeof(p_rtp_hdr);
+        rtp_SetHdr( p_output, p_rtp_hdr );
+
+        for ( i = 1; i < NB_BLOCKS + 1; i++ )
+        {
+            p_iov[i].iov_base = p_output->pp_blocks[i - 1]->p_ts;
+            p_iov[i].iov_len = TS_SIZE;
+        }
+
+        i_outblocks += 1;
+    }
+
+    else
+    {
+        for ( i = 0; i < NB_BLOCKS; i++ )
+        {
+            p_iov[i].iov_base = p_output->pp_blocks[i]->p_ts;
+            p_iov[i].iov_len = TS_SIZE;
+        }
     }
 
-    if ( writev( p_output->i_handle, p_iov, NB_BLOCKS + 1 ) < 0 )
+    if ( writev( p_output->i_handle, p_iov, i_outblocks ) < 0 )
     {
         struct in_addr s;
         s.s_addr = p_output->i_maddr;
-        msg_Err( NULL, "coundn't writev to %s:%u (%s)", inet_ntoa( s ),
+        msg_Err( NULL, "couldn't writev to %s:%u (%s)", inet_ntoa( s ),
                  p_output->i_port, strerror(errno) );
     }
 
diff -ruN trunk/README ajg/README
--- trunk/README	2009-05-25 14:27:45.000000000 +0100
+++ ajg/README	2009-05-24 19:47:17.000000000 +0100
@@ -5,7 +5,12 @@
 configures a CAM module, and demultiplexes the packets to several RTP
 outputs. It supports the new S2API of linux-dvb (compile option).
 
-The configuration file for RTP outputs can be reloaded without losing
+Output to UDP rather than RTP is also supported so those IPTV set top
+boxes that don't do RTP over multicast can also use the streams.  
+This functionality is not recommended and should only be used if
+absolutely necessary.
+
+The configuration file for outputs can be reloaded without losing
 a single packet. MMI operation and monitoring are provided with an
 external control program using a Unix domain socket.
 
@@ -16,3 +21,4 @@
 
 -- 
 Meuuh 2009-05-11
+gatty 2009-05-24
